<?php
/*
Plugin Name: Ratingcaptain-plugin
Description: Integrate your woocommerce shop with ratingcaptain
Author: mathieu.pl
Version: 1.0.0
License: GPLv3
Text Domain: rating-captain
*/
require('php-client/RatingCaptain.php');
if(!class_exists('RatingcaptainPlugin')):
    class RatingcaptainPlugin
    {
        /*
        * AutoLoad Hooks
        */
        public function __construct(){
            register_activation_hook(__FILE__, array(&$this, 'ratingcaptain_install'));
            add_action('admin_menu', array(&$this, 'ratingcaptain_options_page'));
            add_action( 'woocommerce_order_status_completed', array(&$this, 'proccess_backend'));
            add_action('woocommerce_thankyou', array(&$this, 'ratingcaptain_thankyou_page'));
        }

        /*
        * Activation Hook
        */
        public function ratingcaptain_install(){
            $this->ratingcaptain_storeData('', false);
        }
        public function ratingcaptain_thankyou_page($order_id){
            $order = wc_get_order($order_id);
            if($order instanceof WC_Order) {
                $opt = get_option('ratingcaptain_data');
                if ($opt && $opt != '') {
                    $options = json_decode($opt);
                    $is_front_integration = isset($options->ratingcaptain_front_integration) && $options->ratingcaptain_front_integration == true;
                    if (isset($options->api_key) && $is_front_integration) {
                        $to_return_products = "[";
                        foreach ($order->get_items() as $item_id => $item ){
                            $product = $item->get_product();
                            $image_url = wp_get_attachment_image_url( $product->get_image_id(), 'full' );
                            $product_url = get_permalink( $product->get_id());
                            $str = '{
                                "id": "'.$product->get_id().'",
                                "name": "'.$product->get_name().'",
                                "price": "'.$product->get_price().'",
                                "imageUrl": "'.$image_url.'",
                                "product_url": "'.$product_url.'",
                                "sku": "'.$product->get_sku().'"
                            },';
                            $to_return_products = $to_return_products.$str;
                        }
                        $to_return_products = $to_return_products.']';
                        $script__link = 'https://ratingcaptain.com/api/js_v2/'.$options->api_key;
                        $script__link = 'http://127.0.0.1:8001/js_v2/'.$options->api_key;

                        $to_return = ' <script>
                           var RatingCaptain_data_script = {
                                /* REQUIRED | Email, on this address will be send message */
                                    "email": "'.$order->get_billing_email().'",
                                    "name": "'.$order->get_billing_first_name().'",
                                    "surname": "'.$order->get_billing_last_name().'",
                                    "phone": "'.$order->get_billing_phone().'",
                                /* REQUIRED | Order in your system, this field should be unique */
                                    "external_id": "'.$order->get_order_number().'",
                                /* Optional - Products in this order, each product must have id name and price. */
                                "products": '.$to_return_products.'
                            }
                        </script>      
                        <script src="'.$script__link.'"></script>';
                        echo $to_return;
                    }
                }
            }
        }
        public function proccess_backend($order_id){
            $order = wc_get_order($order_id);
            if($order instanceof WC_Order){
                $opt = get_option('ratingcaptain_data');
                if($opt && $opt != ''){
                    $options = json_decode($opt);
                    $is_front_integration = isset($options ->ratingcaptain_front_integration) && $options->ratingcaptain_front_integration == true;
                    if(isset($options->api_key) && !$is_front_integration){
                        $ratingcaptain = new RatingCaptain($options->api_key);
                        if(isset($options->send_products) && $options->send_products != false){
                            foreach ($order->get_items() as $key_data => $item_data){
                                $product = $item_data->get_product();
                                if($product instanceof WC_Product){
                                    $image_id = $product->get_image_id();
                                    if($image_id){
                                        $image_url = wp_get_attachment_image_url($image_id, 'full');
                                    }else{
                                        $image_url = null;
                                    }
                                    $ratingcaptain->addProduct($product->get_id(), $product->get_name(), $product->get_price(), $image_url);
                                }
                            }
                            $res = $ratingcaptain->send(['external_id' => $order->get_order_number(), 'email' => $order->get_billing_email()]);
                        }
                    }
                }
            }
        }
        /*
        * Admin Menu
        */
        public function ratingcaptain_options_page(){
            add_options_page('RatingCaptain Page', 'RatingCaptain Page','manage_options','ratingcaptain_settings',array(&$this, 'ratingcaptain_settings'));
        }

        public function ratingcaptain_storeData($key, $send_products = false){
            add_option('ratingcaptain_data', json_encode(['api_key' => $key, 'send_products' => $send_products]));
        }
        /*
        * Duplicate Page Admin Settings
        */
        public function ratingcaptain_settings(){
            if(current_user_can( 'manage_options' )){
                include('Admin/ratingcaptain_settings.php');
            }
        }
    }
    new RatingcaptainPlugin;
endif;
?>
